.. This is the template for the intro for a provider tutorial
.. You can't include this verbatim as you could with templates/fetch.rst, but you can use it as a starting point

Provisioning {{ provider }} with linchpin
=================================================

LinchPin can be used to provision compute instances on OpenStack.  If you need to familiarize yourself with OpenStack Server, `read this`_. Now let's step through the process of creating a new workspace for provisioning {{ provider }}

.. _read this: https://developer.openstack.org/api-guide/compute/server_concepts.html
